/*******************************************************************************
* File Name: DistOutHCSRO4.c  
* Version 1.90
*
* Description:
*  This file contains API to enable firmware control of a Pins component.
*
* Note:
*
********************************************************************************
* Copyright 2008-2012, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
*******************************************************************************/

#include "cytypes.h"
#include "DistOutHCSRO4.h"


/*******************************************************************************
* Function Name: DistOutHCSRO4_Write
********************************************************************************
*
* Summary:
*  Assign a new value to the digital port's data output register.  
*
* Parameters:  
*  prtValue:  The value to be assigned to the Digital Port. 
*
* Return: 
*  None 
*  
*******************************************************************************/
void DistOutHCSRO4_Write(uint8 value) 
{
    uint8 staticBits = (DistOutHCSRO4_DR & (uint8)(~DistOutHCSRO4_MASK));
    DistOutHCSRO4_DR = staticBits | ((uint8)(value << DistOutHCSRO4_SHIFT) & DistOutHCSRO4_MASK);
}


/*******************************************************************************
* Function Name: DistOutHCSRO4_SetDriveMode
********************************************************************************
*
* Summary:
*  Change the drive mode on the pins of the port.
* 
* Parameters:  
*  mode:  Change the pins to this drive mode.
*
* Return: 
*  None
*
*******************************************************************************/
void DistOutHCSRO4_SetDriveMode(uint8 mode) 
{
	CyPins_SetPinDriveMode(DistOutHCSRO4_0, mode);
}


/*******************************************************************************
* Function Name: DistOutHCSRO4_Read
********************************************************************************
*
* Summary:
*  Read the current value on the pins of the Digital Port in right justified 
*  form.
*
* Parameters:  
*  None 
*
* Return: 
*  Returns the current value of the Digital Port as a right justified number
*  
* Note:
*  Macro DistOutHCSRO4_ReadPS calls this function. 
*  
*******************************************************************************/
uint8 DistOutHCSRO4_Read(void) 
{
    return (DistOutHCSRO4_PS & DistOutHCSRO4_MASK) >> DistOutHCSRO4_SHIFT;
}


/*******************************************************************************
* Function Name: DistOutHCSRO4_ReadDataReg
********************************************************************************
*
* Summary:
*  Read the current value assigned to a Digital Port's data output register
*
* Parameters:  
*  None 
*
* Return: 
*  Returns the current value assigned to the Digital Port's data output register
*  
*******************************************************************************/
uint8 DistOutHCSRO4_ReadDataReg(void) 
{
    return (DistOutHCSRO4_DR & DistOutHCSRO4_MASK) >> DistOutHCSRO4_SHIFT;
}


/* If Interrupts Are Enabled for this Pins component */ 
#if defined(DistOutHCSRO4_INTSTAT) 

    /*******************************************************************************
    * Function Name: DistOutHCSRO4_ClearInterrupt
    ********************************************************************************
    *
    * Summary:
    *  Clears any active interrupts attached to port and returns the value of the 
    *  interrupt status register.
    *
    * Parameters:  
    *  None 
    *
    * Return: 
    *  Returns the value of the interrupt status register
    *  
    *******************************************************************************/
    uint8 DistOutHCSRO4_ClearInterrupt(void) 
    {
        return (DistOutHCSRO4_INTSTAT & DistOutHCSRO4_MASK) >> DistOutHCSRO4_SHIFT;
    }

#endif /* If Interrupts Are Enabled for this Pins component */ 


/* [] END OF FILE */
