/*******************************************************************************
* File Name: DistanceInPulsewidth.c  
* Version 1.90
*
* Description:
*  This file contains API to enable firmware control of a Pins component.
*
* Note:
*
********************************************************************************
* Copyright 2008-2012, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
*******************************************************************************/

#include "cytypes.h"
#include "DistanceInPulsewidth.h"


/*******************************************************************************
* Function Name: DistanceInPulsewidth_Write
********************************************************************************
*
* Summary:
*  Assign a new value to the digital port's data output register.  
*
* Parameters:  
*  prtValue:  The value to be assigned to the Digital Port. 
*
* Return: 
*  None 
*  
*******************************************************************************/
void DistanceInPulsewidth_Write(uint8 value) 
{
    uint8 staticBits = (DistanceInPulsewidth_DR & (uint8)(~DistanceInPulsewidth_MASK));
    DistanceInPulsewidth_DR = staticBits | ((uint8)(value << DistanceInPulsewidth_SHIFT) & DistanceInPulsewidth_MASK);
}


/*******************************************************************************
* Function Name: DistanceInPulsewidth_SetDriveMode
********************************************************************************
*
* Summary:
*  Change the drive mode on the pins of the port.
* 
* Parameters:  
*  mode:  Change the pins to this drive mode.
*
* Return: 
*  None
*
*******************************************************************************/
void DistanceInPulsewidth_SetDriveMode(uint8 mode) 
{
	CyPins_SetPinDriveMode(DistanceInPulsewidth_0, mode);
}


/*******************************************************************************
* Function Name: DistanceInPulsewidth_Read
********************************************************************************
*
* Summary:
*  Read the current value on the pins of the Digital Port in right justified 
*  form.
*
* Parameters:  
*  None 
*
* Return: 
*  Returns the current value of the Digital Port as a right justified number
*  
* Note:
*  Macro DistanceInPulsewidth_ReadPS calls this function. 
*  
*******************************************************************************/
uint8 DistanceInPulsewidth_Read(void) 
{
    return (DistanceInPulsewidth_PS & DistanceInPulsewidth_MASK) >> DistanceInPulsewidth_SHIFT;
}


/*******************************************************************************
* Function Name: DistanceInPulsewidth_ReadDataReg
********************************************************************************
*
* Summary:
*  Read the current value assigned to a Digital Port's data output register
*
* Parameters:  
*  None 
*
* Return: 
*  Returns the current value assigned to the Digital Port's data output register
*  
*******************************************************************************/
uint8 DistanceInPulsewidth_ReadDataReg(void) 
{
    return (DistanceInPulsewidth_DR & DistanceInPulsewidth_MASK) >> DistanceInPulsewidth_SHIFT;
}


/* If Interrupts Are Enabled for this Pins component */ 
#if defined(DistanceInPulsewidth_INTSTAT) 

    /*******************************************************************************
    * Function Name: DistanceInPulsewidth_ClearInterrupt
    ********************************************************************************
    *
    * Summary:
    *  Clears any active interrupts attached to port and returns the value of the 
    *  interrupt status register.
    *
    * Parameters:  
    *  None 
    *
    * Return: 
    *  Returns the value of the interrupt status register
    *  
    *******************************************************************************/
    uint8 DistanceInPulsewidth_ClearInterrupt(void) 
    {
        return (DistanceInPulsewidth_INTSTAT & DistanceInPulsewidth_MASK) >> DistanceInPulsewidth_SHIFT;
    }

#endif /* If Interrupts Are Enabled for this Pins component */ 


/* [] END OF FILE */
