/*******************************************************************************
* File Name: FinMeasISR.c  
* Version 1.70
*
*  Description:
*   API for controlling the state of an interrupt.
*
*
*  Note:
*
********************************************************************************
* Copyright 2008-2012, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
*******************************************************************************/

#include <cydevice_trm.h>
#include <CyLib.h>
#include <FinMeasISR.h>

#if !defined(FinMeasISR__REMOVED) /* Check for removal by optimization */

/*******************************************************************************
*  Place your includes, defines and code here 
********************************************************************************/
/* `#START FinMeasISR_intc` */

	extern uint8 volatile HC_SRO4_EndMeasFlg;
	
/* `#END` */


/*******************************************************************************
* Function Name: FinMeasISR_Start
********************************************************************************
*
* Summary:
*  Set up the interrupt and enable it.
*
* Parameters:  
*   None
*
* Return:
*   None
*
*******************************************************************************/
void FinMeasISR_Start(void) 
{
    /* For all we know the interrupt is active. */
    FinMeasISR_Disable();

    /* Set the ISR to point to the FinMeasISR Interrupt. */
    FinMeasISR_SetVector(&FinMeasISR_Interrupt);

    /* Set the priority. */
    FinMeasISR_SetPriority((uint8)FinMeasISR_INTC_PRIOR_NUMBER);

    /* Enable it. */
    FinMeasISR_Enable();
}


/*******************************************************************************
* Function Name: FinMeasISR_StartEx
********************************************************************************
*
* Summary:
*  Set up the interrupt and enable it.
*
* Parameters:  
*   address: Address of the ISR to set in the interrupt vector table.
*
* Return:
*   None
*
*******************************************************************************/
void FinMeasISR_StartEx(cyisraddress address) 
{
    /* For all we know the interrupt is active. */
    FinMeasISR_Disable();

    /* Set the ISR to point to the FinMeasISR Interrupt. */
    FinMeasISR_SetVector(address);

    /* Set the priority. */
    FinMeasISR_SetPriority((uint8)FinMeasISR_INTC_PRIOR_NUMBER);

    /* Enable it. */
    FinMeasISR_Enable();
}


/*******************************************************************************
* Function Name: FinMeasISR_Stop
********************************************************************************
*
* Summary:
*   Disables and removes the interrupt.
*
* Parameters:  
*   None
*
* Return:
*   None
*
*******************************************************************************/
void FinMeasISR_Stop(void) 
{
    /* Disable this interrupt. */
    FinMeasISR_Disable();
}


/*******************************************************************************
* Function Name: FinMeasISR_Interrupt
********************************************************************************
* Summary:
*   The default Interrupt Service Routine for FinMeasISR.
*
*   Add custom code between the coments to keep the next version of this file
*   from over writting your code.
*
* Parameters:  
*   None
*
* Return:
*   None
*
*******************************************************************************/
CY_ISR(FinMeasISR_Interrupt)
{
    /*  Place your Interrupt code here. */
    /* `#START FinMeasISR_Interrupt` */

	 HC_SRO4_EndMeasFlg = 1;
	
    /* `#END` */

    /* PSoC3 ES1, ES2 RTC ISR PATCH  */ 
    #if(CYDEV_CHIP_FAMILY_USED == CYDEV_CHIP_FAMILY_PSOC3)
        #if((CYDEV_CHIP_REVISION_USED <= CYDEV_CHIP_REVISION_3A_ES2) && (FinMeasISR__ES2_PATCH ))      
            FinMeasISR_ISR_PATCH();
        #endif /* CYDEV_CHIP_REVISION_USED */
    #endif /* (CYDEV_CHIP_FAMILY_USED == CYDEV_CHIP_FAMILY_PSOC3) */
}


/*******************************************************************************
* Function Name: FinMeasISR_SetVector
********************************************************************************
*
* Summary:
*   Change the ISR vector for the Interrupt. Note calling FinMeasISR_Start
*   will override any effect this method would have had. To set the vector 
*   before the component has been started use FinMeasISR_StartEx instead.
*
* Parameters:
*   address: Address of the ISR to set in the interrupt vector table.
*
* Return:
*   None
*
*******************************************************************************/
void FinMeasISR_SetVector(cyisraddress address) 
{
    CY_SET_REG16(FinMeasISR_INTC_VECTOR, (uint16) address);
}


/*******************************************************************************
* Function Name: FinMeasISR_GetVector
********************************************************************************
*
* Summary:
*   Gets the "address" of the current ISR vector for the Interrupt.
*
* Parameters:
*   None
*
* Return:
*   Address of the ISR in the interrupt vector table.
*
*******************************************************************************/
cyisraddress FinMeasISR_GetVector(void) 
{
    return (cyisraddress) CY_GET_REG16(FinMeasISR_INTC_VECTOR);
}


/*******************************************************************************
* Function Name: FinMeasISR_SetPriority
********************************************************************************
*
* Summary:
*   Sets the Priority of the Interrupt. Note calling FinMeasISR_Start
*   or FinMeasISR_StartEx will override any effect this method would 
*   have had. This method should only be called after FinMeasISR_Start or 
*   FinMeasISR_StartEx has been called. To set the initial
*   priority for the component use the cydwr file in the tool.
*
* Parameters:
*   priority: Priority of the interrupt. 0 - 7, 0 being the highest.
*
* Return:
*   None
*
*******************************************************************************/
void FinMeasISR_SetPriority(uint8 priority) 
{
    *FinMeasISR_INTC_PRIOR = priority << 5;
}


/*******************************************************************************
* Function Name: FinMeasISR_GetPriority
********************************************************************************
*
* Summary:
*   Gets the Priority of the Interrupt.
*
* Parameters:
*   None
*
* Return:
*   Priority of the interrupt. 0 - 7, 0 being the highest.
*
*******************************************************************************/
uint8 FinMeasISR_GetPriority(void) 
{
    uint8 priority;


    priority = *FinMeasISR_INTC_PRIOR >> 5;

    return priority;
}


/*******************************************************************************
* Function Name: FinMeasISR_Enable
********************************************************************************
*
* Summary:
*   Enables the interrupt.
*
* Parameters:
*   None
*
* Return:
*   None
*
*******************************************************************************/
void FinMeasISR_Enable(void) 
{
    /* Enable the general interrupt. */
    *FinMeasISR_INTC_SET_EN = FinMeasISR__INTC_MASK;
}


/*******************************************************************************
* Function Name: FinMeasISR_GetState
********************************************************************************
*
* Summary:
*   Gets the state (enabled, disabled) of the Interrupt.
*
* Parameters:
*   None
*
* Return:
*   1 if enabled, 0 if disabled.
*
*******************************************************************************/
uint8 FinMeasISR_GetState(void) 
{
    /* Get the state of the general interrupt. */
    return ((*FinMeasISR_INTC_SET_EN & (uint8)FinMeasISR__INTC_MASK) != 0u) ? 1u:0u;
}


/*******************************************************************************
* Function Name: FinMeasISR_Disable
********************************************************************************
*
* Summary:
*   Disables the Interrupt.
*
* Parameters:
*   None
*
* Return:
*   None
*
*******************************************************************************/
void FinMeasISR_Disable(void) 
{
    /* Disable the general interrupt. */
    *FinMeasISR_INTC_CLR_EN = FinMeasISR__INTC_MASK;
}


/*******************************************************************************
* Function Name: FinMeasISR_SetPending
********************************************************************************
*
* Summary:
*   Causes the Interrupt to enter the pending state, a software method of
*   generating the interrupt.
*
* Parameters:
*   None
*
* Return:
*   None
*
*******************************************************************************/
void FinMeasISR_SetPending(void) 
{
    *FinMeasISR_INTC_SET_PD = FinMeasISR__INTC_MASK;
}


/*******************************************************************************
* Function Name: FinMeasISR_ClearPending
********************************************************************************
*
* Summary:
*   Clears a pending interrupt.
*
* Parameters:
*   None
*
* Return:
*   None
*
*******************************************************************************/
void FinMeasISR_ClearPending(void) 
{
    *FinMeasISR_INTC_CLR_PD = FinMeasISR__INTC_MASK;
}

#endif /* End check for removal by optimization */


/* [] END OF FILE */
