/*******************************************************************************
* File Name: GetDistISR.c  
* Version 1.70
*
*  Description:
*   API for controlling the state of an interrupt.
*
*
*  Note:
*
********************************************************************************
* Copyright 2008-2012, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
*******************************************************************************/

#include <cydevice_trm.h>
#include <CyLib.h>
#include <GetDistISR.h>

#if !defined(GetDistISR__REMOVED) /* Check for removal by optimization */

/*******************************************************************************
*  Place your includes, defines and code here 
********************************************************************************/
/* `#START GetDistISR_intc` */
	
extern uint8 volatile HC_SRO4_EndMeasFlg;

/* `#END` */


/*******************************************************************************
* Function Name: GetDistISR_Start
********************************************************************************
*
* Summary:
*  Set up the interrupt and enable it.
*
* Parameters:  
*   None
*
* Return:
*   None
*
*******************************************************************************/
void GetDistISR_Start(void) 
{
    /* For all we know the interrupt is active. */
    GetDistISR_Disable();

    /* Set the ISR to point to the GetDistISR Interrupt. */
    GetDistISR_SetVector(&GetDistISR_Interrupt);

    /* Set the priority. */
    GetDistISR_SetPriority((uint8)GetDistISR_INTC_PRIOR_NUMBER);

    /* Enable it. */
    GetDistISR_Enable();
}


/*******************************************************************************
* Function Name: GetDistISR_StartEx
********************************************************************************
*
* Summary:
*  Set up the interrupt and enable it.
*
* Parameters:  
*   address: Address of the ISR to set in the interrupt vector table.
*
* Return:
*   None
*
*******************************************************************************/
void GetDistISR_StartEx(cyisraddress address) 
{
    /* For all we know the interrupt is active. */
    GetDistISR_Disable();

    /* Set the ISR to point to the GetDistISR Interrupt. */
    GetDistISR_SetVector(address);

    /* Set the priority. */
    GetDistISR_SetPriority((uint8)GetDistISR_INTC_PRIOR_NUMBER);

    /* Enable it. */
    GetDistISR_Enable();
}


/*******************************************************************************
* Function Name: GetDistISR_Stop
********************************************************************************
*
* Summary:
*   Disables and removes the interrupt.
*
* Parameters:  
*   None
*
* Return:
*   None
*
*******************************************************************************/
void GetDistISR_Stop(void) 
{
    /* Disable this interrupt. */
    GetDistISR_Disable();
}


/*******************************************************************************
* Function Name: GetDistISR_Interrupt
********************************************************************************
* Summary:
*   The default Interrupt Service Routine for GetDistISR.
*
*   Add custom code between the coments to keep the next version of this file
*   from over writting your code.
*
* Parameters:  
*   None
*
* Return:
*   None
*
*******************************************************************************/
CY_ISR(GetDistISR_Interrupt)
{
    /*  Place your Interrupt code here. */
    /* `#START GetDistISR_Interrupt` */
	
	HC_SRO4_EndMeasFlg = 1;							// Flag the end of HC-SRC4 measurement period

    /* `#END` */

    /* PSoC3 ES1, ES2 RTC ISR PATCH  */ 
    #if(CYDEV_CHIP_FAMILY_USED == CYDEV_CHIP_FAMILY_PSOC3)
        #if((CYDEV_CHIP_REVISION_USED <= CYDEV_CHIP_REVISION_3A_ES2) && (GetDistISR__ES2_PATCH ))      
            GetDistISR_ISR_PATCH();
        #endif /* CYDEV_CHIP_REVISION_USED */
    #endif /* (CYDEV_CHIP_FAMILY_USED == CYDEV_CHIP_FAMILY_PSOC3) */
}


/*******************************************************************************
* Function Name: GetDistISR_SetVector
********************************************************************************
*
* Summary:
*   Change the ISR vector for the Interrupt. Note calling GetDistISR_Start
*   will override any effect this method would have had. To set the vector 
*   before the component has been started use GetDistISR_StartEx instead.
*
* Parameters:
*   address: Address of the ISR to set in the interrupt vector table.
*
* Return:
*   None
*
*******************************************************************************/
void GetDistISR_SetVector(cyisraddress address) 
{
    CY_SET_REG16(GetDistISR_INTC_VECTOR, (uint16) address);
}


/*******************************************************************************
* Function Name: GetDistISR_GetVector
********************************************************************************
*
* Summary:
*   Gets the "address" of the current ISR vector for the Interrupt.
*
* Parameters:
*   None
*
* Return:
*   Address of the ISR in the interrupt vector table.
*
*******************************************************************************/
cyisraddress GetDistISR_GetVector(void) 
{
    return (cyisraddress) CY_GET_REG16(GetDistISR_INTC_VECTOR);
}


/*******************************************************************************
* Function Name: GetDistISR_SetPriority
********************************************************************************
*
* Summary:
*   Sets the Priority of the Interrupt. Note calling GetDistISR_Start
*   or GetDistISR_StartEx will override any effect this method would 
*   have had. This method should only be called after GetDistISR_Start or 
*   GetDistISR_StartEx has been called. To set the initial
*   priority for the component use the cydwr file in the tool.
*
* Parameters:
*   priority: Priority of the interrupt. 0 - 7, 0 being the highest.
*
* Return:
*   None
*
*******************************************************************************/
void GetDistISR_SetPriority(uint8 priority) 
{
    *GetDistISR_INTC_PRIOR = priority << 5;
}


/*******************************************************************************
* Function Name: GetDistISR_GetPriority
********************************************************************************
*
* Summary:
*   Gets the Priority of the Interrupt.
*
* Parameters:
*   None
*
* Return:
*   Priority of the interrupt. 0 - 7, 0 being the highest.
*
*******************************************************************************/
uint8 GetDistISR_GetPriority(void) 
{
    uint8 priority;


    priority = *GetDistISR_INTC_PRIOR >> 5;

    return priority;
}


/*******************************************************************************
* Function Name: GetDistISR_Enable
********************************************************************************
*
* Summary:
*   Enables the interrupt.
*
* Parameters:
*   None
*
* Return:
*   None
*
*******************************************************************************/
void GetDistISR_Enable(void) 
{
    /* Enable the general interrupt. */
    *GetDistISR_INTC_SET_EN = GetDistISR__INTC_MASK;
}


/*******************************************************************************
* Function Name: GetDistISR_GetState
********************************************************************************
*
* Summary:
*   Gets the state (enabled, disabled) of the Interrupt.
*
* Parameters:
*   None
*
* Return:
*   1 if enabled, 0 if disabled.
*
*******************************************************************************/
uint8 GetDistISR_GetState(void) 
{
    /* Get the state of the general interrupt. */
    return ((*GetDistISR_INTC_SET_EN & (uint8)GetDistISR__INTC_MASK) != 0u) ? 1u:0u;
}


/*******************************************************************************
* Function Name: GetDistISR_Disable
********************************************************************************
*
* Summary:
*   Disables the Interrupt.
*
* Parameters:
*   None
*
* Return:
*   None
*
*******************************************************************************/
void GetDistISR_Disable(void) 
{
    /* Disable the general interrupt. */
    *GetDistISR_INTC_CLR_EN = GetDistISR__INTC_MASK;
}


/*******************************************************************************
* Function Name: GetDistISR_SetPending
********************************************************************************
*
* Summary:
*   Causes the Interrupt to enter the pending state, a software method of
*   generating the interrupt.
*
* Parameters:
*   None
*
* Return:
*   None
*
*******************************************************************************/
void GetDistISR_SetPending(void) 
{
    *GetDistISR_INTC_SET_PD = GetDistISR__INTC_MASK;
}


/*******************************************************************************
* Function Name: GetDistISR_ClearPending
********************************************************************************
*
* Summary:
*   Clears a pending interrupt.
*
* Parameters:
*   None
*
* Return:
*   None
*
*******************************************************************************/
void GetDistISR_ClearPending(void) 
{
    *GetDistISR_INTC_CLR_PD = GetDistISR__INTC_MASK;
}

#endif /* End check for removal by optimization */


/* [] END OF FILE */
