/*******************************************************************************
* File Name: GetDistance.c  
* Version 1.70
*
*  Description:
*   API for controlling the state of an interrupt.
*
*
*  Note:
*
********************************************************************************
* Copyright 2008-2012, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
*******************************************************************************/

#include <cydevice_trm.h>
#include <CyLib.h>
#include <GetDistance.h>

#if !defined(GetDistance__REMOVED) /* Check for removal by optimization */

/*******************************************************************************
*  Place your includes, defines and code here 
********************************************************************************/
/* `#START GetDistance_intc` */

/* `#END` */


/*******************************************************************************
* Function Name: GetDistance_Start
********************************************************************************
*
* Summary:
*  Set up the interrupt and enable it.
*
* Parameters:  
*   None
*
* Return:
*   None
*
*******************************************************************************/
void GetDistance_Start(void) 
{
    /* For all we know the interrupt is active. */
    GetDistance_Disable();

    /* Set the ISR to point to the GetDistance Interrupt. */
    GetDistance_SetVector(&GetDistance_Interrupt);

    /* Set the priority. */
    GetDistance_SetPriority((uint8)GetDistance_INTC_PRIOR_NUMBER);

    /* Enable it. */
    GetDistance_Enable();
}


/*******************************************************************************
* Function Name: GetDistance_StartEx
********************************************************************************
*
* Summary:
*  Set up the interrupt and enable it.
*
* Parameters:  
*   address: Address of the ISR to set in the interrupt vector table.
*
* Return:
*   None
*
*******************************************************************************/
void GetDistance_StartEx(cyisraddress address) 
{
    /* For all we know the interrupt is active. */
    GetDistance_Disable();

    /* Set the ISR to point to the GetDistance Interrupt. */
    GetDistance_SetVector(address);

    /* Set the priority. */
    GetDistance_SetPriority((uint8)GetDistance_INTC_PRIOR_NUMBER);

    /* Enable it. */
    GetDistance_Enable();
}


/*******************************************************************************
* Function Name: GetDistance_Stop
********************************************************************************
*
* Summary:
*   Disables and removes the interrupt.
*
* Parameters:  
*   None
*
* Return:
*   None
*
*******************************************************************************/
void GetDistance_Stop(void) 
{
    /* Disable this interrupt. */
    GetDistance_Disable();
}


/*******************************************************************************
* Function Name: GetDistance_Interrupt
********************************************************************************
* Summary:
*   The default Interrupt Service Routine for GetDistance.
*
*   Add custom code between the coments to keep the next version of this file
*   from over writting your code.
*
* Parameters:  
*   None
*
* Return:
*   None
*
*******************************************************************************/
CY_ISR(GetDistance_Interrupt)
{
    /*  Place your Interrupt code here. */
    /* `#START GetDistance_Interrupt` */

    /* `#END` */

    /* PSoC3 ES1, ES2 RTC ISR PATCH  */ 
    #if(CYDEV_CHIP_FAMILY_USED == CYDEV_CHIP_FAMILY_PSOC3)
        #if((CYDEV_CHIP_REVISION_USED <= CYDEV_CHIP_REVISION_3A_ES2) && (GetDistance__ES2_PATCH ))      
            GetDistance_ISR_PATCH();
        #endif /* CYDEV_CHIP_REVISION_USED */
    #endif /* (CYDEV_CHIP_FAMILY_USED == CYDEV_CHIP_FAMILY_PSOC3) */
}


/*******************************************************************************
* Function Name: GetDistance_SetVector
********************************************************************************
*
* Summary:
*   Change the ISR vector for the Interrupt. Note calling GetDistance_Start
*   will override any effect this method would have had. To set the vector 
*   before the component has been started use GetDistance_StartEx instead.
*
* Parameters:
*   address: Address of the ISR to set in the interrupt vector table.
*
* Return:
*   None
*
*******************************************************************************/
void GetDistance_SetVector(cyisraddress address) 
{
    CY_SET_REG16(GetDistance_INTC_VECTOR, (uint16) address);
}


/*******************************************************************************
* Function Name: GetDistance_GetVector
********************************************************************************
*
* Summary:
*   Gets the "address" of the current ISR vector for the Interrupt.
*
* Parameters:
*   None
*
* Return:
*   Address of the ISR in the interrupt vector table.
*
*******************************************************************************/
cyisraddress GetDistance_GetVector(void) 
{
    return (cyisraddress) CY_GET_REG16(GetDistance_INTC_VECTOR);
}


/*******************************************************************************
* Function Name: GetDistance_SetPriority
********************************************************************************
*
* Summary:
*   Sets the Priority of the Interrupt. Note calling GetDistance_Start
*   or GetDistance_StartEx will override any effect this method would 
*   have had. This method should only be called after GetDistance_Start or 
*   GetDistance_StartEx has been called. To set the initial
*   priority for the component use the cydwr file in the tool.
*
* Parameters:
*   priority: Priority of the interrupt. 0 - 7, 0 being the highest.
*
* Return:
*   None
*
*******************************************************************************/
void GetDistance_SetPriority(uint8 priority) 
{
    *GetDistance_INTC_PRIOR = priority << 5;
}


/*******************************************************************************
* Function Name: GetDistance_GetPriority
********************************************************************************
*
* Summary:
*   Gets the Priority of the Interrupt.
*
* Parameters:
*   None
*
* Return:
*   Priority of the interrupt. 0 - 7, 0 being the highest.
*
*******************************************************************************/
uint8 GetDistance_GetPriority(void) 
{
    uint8 priority;


    priority = *GetDistance_INTC_PRIOR >> 5;

    return priority;
}


/*******************************************************************************
* Function Name: GetDistance_Enable
********************************************************************************
*
* Summary:
*   Enables the interrupt.
*
* Parameters:
*   None
*
* Return:
*   None
*
*******************************************************************************/
void GetDistance_Enable(void) 
{
    /* Enable the general interrupt. */
    *GetDistance_INTC_SET_EN = GetDistance__INTC_MASK;
}


/*******************************************************************************
* Function Name: GetDistance_GetState
********************************************************************************
*
* Summary:
*   Gets the state (enabled, disabled) of the Interrupt.
*
* Parameters:
*   None
*
* Return:
*   1 if enabled, 0 if disabled.
*
*******************************************************************************/
uint8 GetDistance_GetState(void) 
{
    /* Get the state of the general interrupt. */
    return ((*GetDistance_INTC_SET_EN & (uint8)GetDistance__INTC_MASK) != 0u) ? 1u:0u;
}


/*******************************************************************************
* Function Name: GetDistance_Disable
********************************************************************************
*
* Summary:
*   Disables the Interrupt.
*
* Parameters:
*   None
*
* Return:
*   None
*
*******************************************************************************/
void GetDistance_Disable(void) 
{
    /* Disable the general interrupt. */
    *GetDistance_INTC_CLR_EN = GetDistance__INTC_MASK;
}


/*******************************************************************************
* Function Name: GetDistance_SetPending
********************************************************************************
*
* Summary:
*   Causes the Interrupt to enter the pending state, a software method of
*   generating the interrupt.
*
* Parameters:
*   None
*
* Return:
*   None
*
*******************************************************************************/
void GetDistance_SetPending(void) 
{
    *GetDistance_INTC_SET_PD = GetDistance__INTC_MASK;
}


/*******************************************************************************
* Function Name: GetDistance_ClearPending
********************************************************************************
*
* Summary:
*   Clears a pending interrupt.
*
* Parameters:
*   None
*
* Return:
*   None
*
*******************************************************************************/
void GetDistance_ClearPending(void) 
{
    *GetDistance_INTC_CLR_PD = GetDistance__INTC_MASK;
}

#endif /* End check for removal by optimization */


/* [] END OF FILE */
