/*******************************************************************************
* File Name: PWMtriggen.h  
* Version 3.0
*
* Description:
*  Contains the prototypes and constants for the functions available to the 
*  PWM user module.
*
* Note:
*
********************************************************************************
* Copyright 2008-2012, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
********************************************************************************/

#if !defined(CY_PWM_PWMtriggen_H)
#define CY_PWM_PWMtriggen_H

#include "cytypes.h"
#include "cyfitter.h"
#include "CyLib.h" /* For CyEnterCriticalSection() and CyExitCriticalSection() functions */

extern uint8 PWMtriggen_initVar;


/***************************************
* Conditional Compilation Parameters
***************************************/
#define PWMtriggen_Resolution 8u
#define PWMtriggen_UsingFixedFunction 0u
#define PWMtriggen_DeadBandMode 0u
#define PWMtriggen_KillModeMinTime 0u
#define PWMtriggen_KillMode 0u
#define PWMtriggen_PWMMode 0u
#define PWMtriggen_PWMModeIsCenterAligned 0u
#define PWMtriggen_DeadBandUsed 0u
#define PWMtriggen_DeadBand2_4 0u

#if !defined(PWMtriggen_PWMUDB_genblk8_stsreg__REMOVED)
    #define PWMtriggen_UseStatus 1u
#else
    #define PWMtriggen_UseStatus 0u
#endif /* !defined(PWMtriggen_PWMUDB_genblk8_stsreg__REMOVED) */

#if !defined(PWMtriggen_PWMUDB_genblk1_ctrlreg__REMOVED)
    #define PWMtriggen_UseControl 1u
#else
    #define PWMtriggen_UseControl 0u
#endif /* !defined(PWMtriggen_PWMUDB_genblk1_ctrlreg__REMOVED) */
#define PWMtriggen_UseOneCompareMode 1u
#define PWMtriggen_MinimumKillTime 1u
#define PWMtriggen_EnableMode 0u

#define PWMtriggen_CompareMode1SW 0u
#define PWMtriggen_CompareMode2SW 0u

/* Check to see if required defines such as CY_PSOC5LP are available */
/* They are defined starting with cy_boot v3.0 */
#if !defined (CY_PSOC5LP)
    #error Component PWM_v3_0 requires cy_boot v3.0 or later
#endif /* (CY_ PSOC5LP) */

/* Use Kill Mode Enumerated Types */
#define PWMtriggen__B_PWM__DISABLED 0
#define PWMtriggen__B_PWM__ASYNCHRONOUS 1
#define PWMtriggen__B_PWM__SINGLECYCLE 2
#define PWMtriggen__B_PWM__LATCHED 3
#define PWMtriggen__B_PWM__MINTIME 4


/* Use Dead Band Mode Enumerated Types */
#define PWMtriggen__B_PWM__DBMDISABLED 0
#define PWMtriggen__B_PWM__DBM_2_4_CLOCKS 1
#define PWMtriggen__B_PWM__DBM_256_CLOCKS 2


/* Used PWM Mode Enumerated Types */
#define PWMtriggen__B_PWM__ONE_OUTPUT 0
#define PWMtriggen__B_PWM__TWO_OUTPUTS 1
#define PWMtriggen__B_PWM__DUAL_EDGE 2
#define PWMtriggen__B_PWM__CENTER_ALIGN 3
#define PWMtriggen__B_PWM__DITHER 5
#define PWMtriggen__B_PWM__HARDWARESELECT 4


/* Used PWM Compare Mode Enumerated Types */
#define PWMtriggen__B_PWM__LESS_THAN 1
#define PWMtriggen__B_PWM__LESS_THAN_OR_EQUAL 2
#define PWMtriggen__B_PWM__GREATER_THAN 3
#define PWMtriggen__B_PWM__GREATER_THAN_OR_EQUAL_TO 4
#define PWMtriggen__B_PWM__EQUAL 0
#define PWMtriggen__B_PWM__FIRMWARE 5



/***************************************
* Data Struct Definition
***************************************/


/**************************************************************************
 * Sleep Wakeup Backup structure for PWM Component
 *************************************************************************/
typedef struct
{
    
    uint8 PWMEnableState;
       
    #if(!PWMtriggen_UsingFixedFunction)
        uint8 PWMUdb;               /* PWM Current Counter value  */
        #if(!PWMtriggen_PWMModeIsCenterAligned)
            uint8 PWMPeriod;
        #endif /* (!PWMtriggen_PWMModeIsCenterAligned) */
        #if (PWMtriggen_UseStatus)
            uint8 InterruptMaskValue;   /* PWM Current Interrupt Mask */
        #endif /* (PWMtriggen_UseStatus) */
        
        /* Backup for Deadband parameters */
        #if(PWMtriggen_DeadBandMode == PWMtriggen__B_PWM__DBM_256_CLOCKS || \
            PWMtriggen_DeadBandMode == PWMtriggen__B_PWM__DBM_2_4_CLOCKS)
            uint8 PWMdeadBandValue; /* Dead Band Counter Current Value */
        #endif /* deadband count is either 2-4 clocks or 256 clocks */
        
        /* Backup Kill Mode Counter*/
        #if(PWMtriggen_KillModeMinTime)
            uint8 PWMKillCounterPeriod; /* Kill Mode period value */
        #endif /* (PWMtriggen_KillModeMinTime) */
       
        /* Backup control register */
        #if(PWMtriggen_UseControl)
            uint8 PWMControlRegister; /* PWM Control Register value */
        #endif /* (PWMtriggen_UseControl) */
        
    #endif /* (!PWMtriggen_UsingFixedFunction) */
   
}PWMtriggen_backupStruct;


/***************************************
*        Function Prototypes
 **************************************/
 
void    PWMtriggen_Start(void) ;
void    PWMtriggen_Stop(void) ;

#if (PWMtriggen_UseStatus || PWMtriggen_UsingFixedFunction)
    void  PWMtriggen_SetInterruptMode(uint8 interruptMode) ;
    uint8 PWMtriggen_ReadStatusRegister(void) ;
#endif /* (PWMtriggen_UseStatus || PWMtriggen_UsingFixedFunction) */

#define PWMtriggen_GetInterruptSource() PWMtriggen_ReadStatusRegister()

#if (PWMtriggen_UseControl)
    uint8 PWMtriggen_ReadControlRegister(void) ; 
    void  PWMtriggen_WriteControlRegister(uint8 control) ;
#endif /* (PWMtriggen_UseControl) */

#if (PWMtriggen_UseOneCompareMode)
   #if (PWMtriggen_CompareMode1SW)
       void    PWMtriggen_SetCompareMode(uint8 comparemode) ;
   #endif /* (PWMtriggen_CompareMode1SW) */
#else
    #if (PWMtriggen_CompareMode1SW)
        void    PWMtriggen_SetCompareMode1(uint8 comparemode) ;
    #endif /* (PWMtriggen_CompareMode1SW) */
    #if (PWMtriggen_CompareMode2SW)
        void    PWMtriggen_SetCompareMode2(uint8 comparemode) ;
    #endif /* (PWMtriggen_CompareMode2SW) */
#endif /* (PWMtriggen_UseOneCompareMode) */

#if (!PWMtriggen_UsingFixedFunction)
    uint8   PWMtriggen_ReadCounter(void) ;
    uint8 PWMtriggen_ReadCapture(void) ;
    
	#if (PWMtriggen_UseStatus)
	        void PWMtriggen_ClearFIFO(void) ;
	#endif /* (PWMtriggen_UseStatus) */

    void    PWMtriggen_WriteCounter(uint8 counter) ;
#endif /* (!PWMtriggen_UsingFixedFunction) */

void    PWMtriggen_WritePeriod(uint8 period) ;
uint8 PWMtriggen_ReadPeriod(void) ;

#if (PWMtriggen_UseOneCompareMode)
    void    PWMtriggen_WriteCompare(uint8 compare) ;
    uint8 PWMtriggen_ReadCompare(void) ; 
#else
    void    PWMtriggen_WriteCompare1(uint8 compare) ;
    uint8 PWMtriggen_ReadCompare1(void) ; 
    void    PWMtriggen_WriteCompare2(uint8 compare) ;
    uint8 PWMtriggen_ReadCompare2(void) ; 
#endif /* (PWMtriggen_UseOneCompareMode) */


#if (PWMtriggen_DeadBandUsed)
    void    PWMtriggen_WriteDeadTime(uint8 deadtime) ;
    uint8   PWMtriggen_ReadDeadTime(void) ;
#endif /* (PWMtriggen_DeadBandUsed) */

#if ( PWMtriggen_KillModeMinTime)
    void PWMtriggen_WriteKillTime(uint8 killtime) ;
    uint8 PWMtriggen_ReadKillTime(void) ; 
#endif /* ( PWMtriggen_KillModeMinTime) */

void PWMtriggen_Init(void) ;
void PWMtriggen_Enable(void) ;
void PWMtriggen_Sleep(void) ;
void PWMtriggen_Wakeup(void) ;
void PWMtriggen_SaveConfig(void) ;
void PWMtriggen_RestoreConfig(void) ;


/***************************************
*         Initialization Values
**************************************/
#define PWMtriggen_INIT_PERIOD_VALUE        99u
#define PWMtriggen_INIT_COMPARE_VALUE1      10u
#define PWMtriggen_INIT_COMPARE_VALUE2      63u
#define PWMtriggen_INIT_INTERRUPTS_MODE     (uint8)(((uint8)(0u << PWMtriggen_STATUS_TC_INT_EN_MASK_SHIFT)) | \
                                                  (uint8)((uint8)(0u << PWMtriggen_STATUS_CMP2_INT_EN_MASK_SHIFT)) | \
                                                  (uint8)((uint8)(0u << PWMtriggen_STATUS_CMP1_INT_EN_MASK_SHIFT )) | \
                                                  (uint8)((uint8)(0u << PWMtriggen_STATUS_KILL_INT_EN_MASK_SHIFT )))
#define PWMtriggen_DEFAULT_COMPARE2_MODE    (uint8)((uint8)1u << PWMtriggen_CTRL_CMPMODE2_SHIFT)
#define PWMtriggen_DEFAULT_COMPARE1_MODE    (uint8)((uint8)1u << PWMtriggen_CTRL_CMPMODE1_SHIFT)
#define PWMtriggen_INIT_DEAD_TIME           1u


/********************************
*         Registers
******************************** */

#if (PWMtriggen_UsingFixedFunction)
   #define PWMtriggen_PERIOD_LSB          (*(reg16 *) PWMtriggen_PWMHW__PER0)
   #define PWMtriggen_PERIOD_LSB_PTR      ( (reg16 *) PWMtriggen_PWMHW__PER0)
   #define PWMtriggen_COMPARE1_LSB        (*(reg16 *) PWMtriggen_PWMHW__CNT_CMP0)
   #define PWMtriggen_COMPARE1_LSB_PTR    ( (reg16 *) PWMtriggen_PWMHW__CNT_CMP0)
   #define PWMtriggen_COMPARE2_LSB        0x00u
   #define PWMtriggen_COMPARE2_LSB_PTR    0x00u
   #define PWMtriggen_COUNTER_LSB         (*(reg16 *) PWMtriggen_PWMHW__CNT_CMP0)
   #define PWMtriggen_COUNTER_LSB_PTR     ( (reg16 *) PWMtriggen_PWMHW__CNT_CMP0)
   #define PWMtriggen_CAPTURE_LSB         (*(reg16 *) PWMtriggen_PWMHW__CAP0)
   #define PWMtriggen_CAPTURE_LSB_PTR     ( (reg16 *) PWMtriggen_PWMHW__CAP0)
   #define PWMtriggen_RT1                 (*(reg8 *)  PWMtriggen_PWMHW__RT1)
   #define PWMtriggen_RT1_PTR             ( (reg8 *)  PWMtriggen_PWMHW__RT1)
      
#else
   #if (PWMtriggen_Resolution == 8u) /* 8bit - PWM */
	   
	   #if(PWMtriggen_PWMModeIsCenterAligned)
	       #define PWMtriggen_PERIOD_LSB      (*(reg8 *) PWMtriggen_PWMUDB_sP8_pwmdp_u0__D1_REG)
	       #define PWMtriggen_PERIOD_LSB_PTR   ((reg8 *) PWMtriggen_PWMUDB_sP8_pwmdp_u0__D1_REG)
	   #else
	       #define PWMtriggen_PERIOD_LSB      (*(reg8 *) PWMtriggen_PWMUDB_sP8_pwmdp_u0__F0_REG)
	       #define PWMtriggen_PERIOD_LSB_PTR   ((reg8 *) PWMtriggen_PWMUDB_sP8_pwmdp_u0__F0_REG)
	   #endif /* (PWMtriggen_PWMModeIsCenterAligned) */
	   
	   #define PWMtriggen_COMPARE1_LSB    (*(reg8 *) PWMtriggen_PWMUDB_sP8_pwmdp_u0__D0_REG)
	   #define PWMtriggen_COMPARE1_LSB_PTR ((reg8 *) PWMtriggen_PWMUDB_sP8_pwmdp_u0__D0_REG)
	   #define PWMtriggen_COMPARE2_LSB    (*(reg8 *) PWMtriggen_PWMUDB_sP8_pwmdp_u0__D1_REG)
	   #define PWMtriggen_COMPARE2_LSB_PTR ((reg8 *) PWMtriggen_PWMUDB_sP8_pwmdp_u0__D1_REG)
	   #define PWMtriggen_COUNTERCAP_LSB   (*(reg8 *) PWMtriggen_PWMUDB_sP8_pwmdp_u0__A1_REG)
	   #define PWMtriggen_COUNTERCAP_LSB_PTR ((reg8 *) PWMtriggen_PWMUDB_sP8_pwmdp_u0__A1_REG)
	   #define PWMtriggen_COUNTER_LSB     (*(reg8 *) PWMtriggen_PWMUDB_sP8_pwmdp_u0__A0_REG)
	   #define PWMtriggen_COUNTER_LSB_PTR  ((reg8 *) PWMtriggen_PWMUDB_sP8_pwmdp_u0__A0_REG)
	   #define PWMtriggen_CAPTURE_LSB     (*(reg8 *) PWMtriggen_PWMUDB_sP8_pwmdp_u0__F1_REG)
	   #define PWMtriggen_CAPTURE_LSB_PTR  ((reg8 *) PWMtriggen_PWMUDB_sP8_pwmdp_u0__F1_REG)
   
   #else
   		#if(CY_PSOC3) /* 8-bit address space */	
			#if(PWMtriggen_PWMModeIsCenterAligned)
		       #define PWMtriggen_PERIOD_LSB      (*(reg16 *) PWMtriggen_PWMUDB_sP8_pwmdp_u0__D1_REG)
		       #define PWMtriggen_PERIOD_LSB_PTR   ((reg16 *) PWMtriggen_PWMUDB_sP8_pwmdp_u0__D1_REG)
		    #else
		       #define PWMtriggen_PERIOD_LSB      (*(reg16 *) PWMtriggen_PWMUDB_sP8_pwmdp_u0__F0_REG)
		       #define PWMtriggen_PERIOD_LSB_PTR   ((reg16 *) PWMtriggen_PWMUDB_sP8_pwmdp_u0__F0_REG)
		    #endif /* (PWMtriggen_PWMModeIsCenterAligned) */
		   
		    #define PWMtriggen_COMPARE1_LSB    (*(reg16 *) PWMtriggen_PWMUDB_sP8_pwmdp_u0__D0_REG)
		    #define PWMtriggen_COMPARE1_LSB_PTR ((reg16 *) PWMtriggen_PWMUDB_sP8_pwmdp_u0__D0_REG)
		    #define PWMtriggen_COMPARE2_LSB    (*(reg16 *) PWMtriggen_PWMUDB_sP8_pwmdp_u0__D1_REG)
		    #define PWMtriggen_COMPARE2_LSB_PTR ((reg16 *) PWMtriggen_PWMUDB_sP8_pwmdp_u0__D1_REG)
		    #define PWMtriggen_COUNTERCAP_LSB   (*(reg16 *) PWMtriggen_PWMUDB_sP8_pwmdp_u0__A1_REG)
		    #define PWMtriggen_COUNTERCAP_LSB_PTR ((reg16 *) PWMtriggen_PWMUDB_sP8_pwmdp_u0__A1_REG)
		    #define PWMtriggen_COUNTER_LSB     (*(reg16 *) PWMtriggen_PWMUDB_sP8_pwmdp_u0__A0_REG)
		    #define PWMtriggen_COUNTER_LSB_PTR  ((reg16 *) PWMtriggen_PWMUDB_sP8_pwmdp_u0__A0_REG)
		    #define PWMtriggen_CAPTURE_LSB     (*(reg16 *) PWMtriggen_PWMUDB_sP8_pwmdp_u0__F1_REG)
		    #define PWMtriggen_CAPTURE_LSB_PTR  ((reg16 *) PWMtriggen_PWMUDB_sP8_pwmdp_u0__F1_REG)
		#else
			#if(PWMtriggen_PWMModeIsCenterAligned)
		       #define PWMtriggen_PERIOD_LSB      (*(reg16 *) PWMtriggen_PWMUDB_sP8_pwmdp_u0__16BIT_D1_REG)
		       #define PWMtriggen_PERIOD_LSB_PTR   ((reg16 *) PWMtriggen_PWMUDB_sP8_pwmdp_u0__16BIT_D1_REG)
		    #else
		       #define PWMtriggen_PERIOD_LSB      (*(reg16 *) PWMtriggen_PWMUDB_sP8_pwmdp_u0__16BIT_F0_REG)
		       #define PWMtriggen_PERIOD_LSB_PTR   ((reg16 *) PWMtriggen_PWMUDB_sP8_pwmdp_u0__16BIT_F0_REG)
		    #endif /* (PWMtriggen_PWMModeIsCenterAligned) */
		   
		    #define PWMtriggen_COMPARE1_LSB    (*(reg16 *) PWMtriggen_PWMUDB_sP8_pwmdp_u0__16BIT_D0_REG)
		    #define PWMtriggen_COMPARE1_LSB_PTR ((reg16 *) PWMtriggen_PWMUDB_sP8_pwmdp_u0__16BIT_D0_REG)
		    #define PWMtriggen_COMPARE2_LSB    (*(reg16 *) PWMtriggen_PWMUDB_sP8_pwmdp_u0__16BIT_D1_REG)
		    #define PWMtriggen_COMPARE2_LSB_PTR ((reg16 *) PWMtriggen_PWMUDB_sP8_pwmdp_u0__16BIT_D1_REG)
		    #define PWMtriggen_COUNTERCAP_LSB   (*(reg16 *) PWMtriggen_PWMUDB_sP8_pwmdp_u0__16BIT_A1_REG)
		    #define PWMtriggen_COUNTERCAP_LSB_PTR ((reg16 *) PWMtriggen_PWMUDB_sP8_pwmdp_u0__16BIT_A1_REG)
		    #define PWMtriggen_COUNTER_LSB     (*(reg16 *) PWMtriggen_PWMUDB_sP8_pwmdp_u0__16BIT_A0_REG)
		    #define PWMtriggen_COUNTER_LSB_PTR  ((reg16 *) PWMtriggen_PWMUDB_sP8_pwmdp_u0__16BIT_A0_REG)
		    #define PWMtriggen_CAPTURE_LSB     (*(reg16 *) PWMtriggen_PWMUDB_sP8_pwmdp_u0__16BIT_F1_REG)
		    #define PWMtriggen_CAPTURE_LSB_PTR  ((reg16 *) PWMtriggen_PWMUDB_sP8_pwmdp_u0__16BIT_F1_REG)
		#endif
		
	   #define PWMtriggen_AUX_CONTROLDP1    (*(reg8 *) PWMtriggen_PWMUDB_sP8_pwmdp_u1__DP_AUX_CTL_REG)
       #define PWMtriggen_AUX_CONTROLDP1_PTR  ((reg8 *) PWMtriggen_PWMUDB_sP8_pwmdp_u1__DP_AUX_CTL_REG)

   #endif /* (PWMtriggen_Resolution == 8) */
   
   #define PWMtriggen_AUX_CONTROLDP0      (*(reg8 *) PWMtriggen_PWMUDB_sP8_pwmdp_u0__DP_AUX_CTL_REG)
   #define PWMtriggen_AUX_CONTROLDP0_PTR  ((reg8 *) PWMtriggen_PWMUDB_sP8_pwmdp_u0__DP_AUX_CTL_REG)

#endif /* (PWMtriggen_UsingFixedFunction) */
   
#if(PWMtriggen_KillModeMinTime )
    #define PWMtriggen_KILLMODEMINTIME      (*(reg8 *) PWMtriggen_PWMUDB_sKM_killmodecounterdp_u0__D0_REG)
    #define PWMtriggen_KILLMODEMINTIME_PTR   ((reg8 *) PWMtriggen_PWMUDB_sKM_killmodecounterdp_u0__D0_REG)
    /* Fixed Function Block has no Kill Mode parameters because it is Asynchronous only */
#endif /* (PWMtriggen_KillModeMinTime ) */

#if(PWMtriggen_DeadBandMode == PWMtriggen__B_PWM__DBM_256_CLOCKS)
    #define PWMtriggen_DEADBAND_COUNT      (*(reg8 *) PWMtriggen_PWMUDB_sDB255_deadbandcounterdp_u0__D0_REG)
    #define PWMtriggen_DEADBAND_COUNT_PTR  ((reg8 *) PWMtriggen_PWMUDB_sDB255_deadbandcounterdp_u0__D0_REG)
    #define PWMtriggen_DEADBAND_LSB_PTR    ((reg8 *) PWMtriggen_PWMUDB_sDB255_deadbandcounterdp_u0__A0_REG)
    #define PWMtriggen_DEADBAND_LSB        (*(reg8 *) PWMtriggen_PWMUDB_sDB255_deadbandcounterdp_u0__A0_REG)
#elif(PWMtriggen_DeadBandMode == PWMtriggen__B_PWM__DBM_2_4_CLOCKS)
    /* In Fixed Function Block these bits are in the control blocks control register */
    #if (PWMtriggen_UsingFixedFunction)
        #define PWMtriggen_DEADBAND_COUNT        (*(reg8 *) PWMtriggen_PWMHW__CFG0) 
        #define PWMtriggen_DEADBAND_COUNT_PTR     ((reg8 *) PWMtriggen_PWMHW__CFG0)
        #define PWMtriggen_DEADBAND_COUNT_MASK    (uint8)((uint8)0x03u << PWMtriggen_DEADBAND_COUNT_SHIFT)
        /* As defined by the Register Map as DEADBAND_PERIOD[1:0] in CFG0 */
        #define PWMtriggen_DEADBAND_COUNT_SHIFT   0x06u  
    #else
        /* Lower two bits of the added control register define the count 1-3 */
        #define PWMtriggen_DEADBAND_COUNT        (*(reg8 *) PWMtriggen_PWMUDB_genblk7_dbctrlreg__CONTROL_REG)
        #define PWMtriggen_DEADBAND_COUNT_PTR     ((reg8 *) PWMtriggen_PWMUDB_genblk7_dbctrlreg__CONTROL_REG)
        #define PWMtriggen_DEADBAND_COUNT_MASK    (uint8)((uint8)0x03u << PWMtriggen_DEADBAND_COUNT_SHIFT) 
        /* As defined by the verilog implementation of the Control Register */
        #define PWMtriggen_DEADBAND_COUNT_SHIFT   0x00u 
    #endif /* (PWMtriggen_UsingFixedFunction) */
#endif /* (PWMtriggen_DeadBandMode == PWMtriggen__B_PWM__DBM_256_CLOCKS) */



#if (PWMtriggen_UsingFixedFunction)
    #define PWMtriggen_STATUS                (*(reg8 *) PWMtriggen_PWMHW__SR0)
    #define PWMtriggen_STATUS_PTR            ((reg8 *) PWMtriggen_PWMHW__SR0)
    #define PWMtriggen_STATUS_MASK           (*(reg8 *) PWMtriggen_PWMHW__SR0)
    #define PWMtriggen_STATUS_MASK_PTR       ((reg8 *) PWMtriggen_PWMHW__SR0)
    #define PWMtriggen_CONTROL               (*(reg8 *) PWMtriggen_PWMHW__CFG0)
    #define PWMtriggen_CONTROL_PTR           ((reg8 *) PWMtriggen_PWMHW__CFG0)    
    #define PWMtriggen_CONTROL2              (*(reg8 *) PWMtriggen_PWMHW__CFG1)    
    #define PWMtriggen_CONTROL3              (*(reg8 *) PWMtriggen_PWMHW__CFG2)
    #define PWMtriggen_GLOBAL_ENABLE         (*(reg8 *) PWMtriggen_PWMHW__PM_ACT_CFG)
    #define PWMtriggen_GLOBAL_ENABLE_PTR       ( (reg8 *) PWMtriggen_PWMHW__PM_ACT_CFG)
    #define PWMtriggen_GLOBAL_STBY_ENABLE      (*(reg8 *) PWMtriggen_PWMHW__PM_STBY_CFG)
    #define PWMtriggen_GLOBAL_STBY_ENABLE_PTR  ( (reg8 *) PWMtriggen_PWMHW__PM_STBY_CFG)
  
  
    /***********************************
    *          Constants
    ***********************************/

    /* Fixed Function Block Chosen */
    #define PWMtriggen_BLOCK_EN_MASK          PWMtriggen_PWMHW__PM_ACT_MSK
    #define PWMtriggen_BLOCK_STBY_EN_MASK     PWMtriggen_PWMHW__PM_STBY_MSK 
    /* Control Register definitions */
    #define PWMtriggen_CTRL_ENABLE_SHIFT      0x00u
    
    #define PWMtriggen_CTRL_CMPMODE1_SHIFT    0x04u  /* As defined by Register map as MODE_CFG bits in CFG2*/
    
    #define PWMtriggen_CTRL_DEAD_TIME_SHIFT   0x06u   /* As defined by Register map */

    /* Fixed Function Block Only CFG register bit definitions */
    #define PWMtriggen_CFG0_MODE              0x02u   /*  Set to compare mode */
    
    /* #define PWMtriggen_CFG0_ENABLE            0x01u */  /* Enable the block to run */
    #define PWMtriggen_CFG0_DB                0x20u   /* As defined by Register map as DB bit in CFG0 */

    /* Control Register Bit Masks */
    #define PWMtriggen_CTRL_ENABLE            (uint8)((uint8)0x01u << PWMtriggen_CTRL_ENABLE_SHIFT)
    #define PWMtriggen_CTRL_RESET             (uint8)((uint8)0x01u << PWMtriggen_CTRL_RESET_SHIFT)
    #define PWMtriggen_CTRL_CMPMODE2_MASK     (uint8)((uint8)0x07u << PWMtriggen_CTRL_CMPMODE2_SHIFT)
    #define PWMtriggen_CTRL_CMPMODE1_MASK     (uint8)((uint8)0x07u << PWMtriggen_CTRL_CMPMODE1_SHIFT)
    
    /* Control2 Register Bit Masks */
    /* As defined in Register Map, Part of the TMRX_CFG1 register */
    #define PWMtriggen_CTRL2_IRQ_SEL_SHIFT    0x00u       
    #define PWMtriggen_CTRL2_IRQ_SEL          (uint8)((uint8)0x01u << PWMtriggen_CTRL2_IRQ_SEL_SHIFT)  
    
    /* Status Register Bit Locations */
    #define PWMtriggen_STATUS_TC_SHIFT            0x07u   /* As defined by Register map as TC in SR0 */
    #define PWMtriggen_STATUS_CMP1_SHIFT          0x06u   /* As defined by the Register map as CAP_CMP in SR0 */
    
    /* Status Register Interrupt Enable Bit Locations */
    #define PWMtriggen_STATUS_KILL_INT_EN_MASK_SHIFT          (0x00u)    
    #define PWMtriggen_STATUS_TC_INT_EN_MASK_SHIFT            (PWMtriggen_STATUS_TC_SHIFT - 4u)
    #define PWMtriggen_STATUS_CMP2_INT_EN_MASK_SHIFT          (0x00u)  
    #define PWMtriggen_STATUS_CMP1_INT_EN_MASK_SHIFT          (PWMtriggen_STATUS_CMP1_SHIFT - 4u)
    
    /* Status Register Bit Masks */
    #define PWMtriggen_STATUS_TC              (uint8)((uint8)0x01u << PWMtriggen_STATUS_TC_SHIFT)
    #define PWMtriggen_STATUS_CMP1            (uint8)((uint8)0x01u << PWMtriggen_STATUS_CMP1_SHIFT)
    
    /* Status Register Interrupt Bit Masks */
    #define PWMtriggen_STATUS_TC_INT_EN_MASK              (uint8)((uint8)PWMtriggen_STATUS_TC >> 4u)
    #define PWMtriggen_STATUS_CMP1_INT_EN_MASK            (uint8)((uint8)PWMtriggen_STATUS_CMP1 >> 4u)
    
    /*RT1 Synch Constants */
    #define PWMtriggen_RT1_SHIFT             0x04u
    #define PWMtriggen_RT1_MASK              (uint8)((uint8)0x03u << PWMtriggen_RT1_SHIFT)/* Sync TC and CMP bit masks */
    #define PWMtriggen_SYNC                  (uint8)((uint8)0x03u << PWMtriggen_RT1_SHIFT)
    #define PWMtriggen_SYNCDSI_SHIFT         0x00u
    #define PWMtriggen_SYNCDSI_MASK          (uint8)((uint8)0x0Fu << PWMtriggen_SYNCDSI_SHIFT) /* Sync all DSI inputs */
    #define PWMtriggen_SYNCDSI_EN            (uint8)((uint8)0x0Fu << PWMtriggen_SYNCDSI_SHIFT) /* Sync all DSI inputs */
    

#else
    #define PWMtriggen_STATUS                (*(reg8 *) PWMtriggen_PWMUDB_genblk8_stsreg__STATUS_REG )
    #define PWMtriggen_STATUS_PTR            ((reg8 *) PWMtriggen_PWMUDB_genblk8_stsreg__STATUS_REG )
    #define PWMtriggen_STATUS_MASK           (*(reg8 *) PWMtriggen_PWMUDB_genblk8_stsreg__MASK_REG)
    #define PWMtriggen_STATUS_MASK_PTR       ((reg8 *) PWMtriggen_PWMUDB_genblk8_stsreg__MASK_REG)
    #define PWMtriggen_STATUS_AUX_CTRL       (*(reg8 *) PWMtriggen_PWMUDB_genblk8_stsreg__STATUS_AUX_CTL_REG)
    #define PWMtriggen_CONTROL               (*(reg8 *) PWMtriggen_PWMUDB_genblk1_ctrlreg__CONTROL_REG)
    #define PWMtriggen_CONTROL_PTR           ((reg8 *) PWMtriggen_PWMUDB_genblk1_ctrlreg__CONTROL_REG)
    
    
    /***********************************
    *          Constants
    ***********************************/

    /* Control Register definitions */
    #define PWMtriggen_CTRL_ENABLE_SHIFT      0x07u
    #define PWMtriggen_CTRL_RESET_SHIFT       0x06u
    #define PWMtriggen_CTRL_CMPMODE2_SHIFT    0x03u
    #define PWMtriggen_CTRL_CMPMODE1_SHIFT    0x00u
    #define PWMtriggen_CTRL_DEAD_TIME_SHIFT   0x00u   /* No Shift Needed for UDB block */
    /* Control Register Bit Masks */
    #define PWMtriggen_CTRL_ENABLE            (uint8)((uint8)0x01u << PWMtriggen_CTRL_ENABLE_SHIFT)
    #define PWMtriggen_CTRL_RESET             (uint8)((uint8)0x01u << PWMtriggen_CTRL_RESET_SHIFT)
    #define PWMtriggen_CTRL_CMPMODE2_MASK     (uint8)((uint8)0x07u << PWMtriggen_CTRL_CMPMODE2_SHIFT)
    #define PWMtriggen_CTRL_CMPMODE1_MASK     (uint8)((uint8)0x07u << PWMtriggen_CTRL_CMPMODE1_SHIFT) 
    
    /* Status Register Bit Locations */
    #define PWMtriggen_STATUS_KILL_SHIFT          0x05u
    #define PWMtriggen_STATUS_FIFONEMPTY_SHIFT    0x04u
    #define PWMtriggen_STATUS_FIFOFULL_SHIFT      0x03u  
    #define PWMtriggen_STATUS_TC_SHIFT            0x02u
    #define PWMtriggen_STATUS_CMP2_SHIFT          0x01u
    #define PWMtriggen_STATUS_CMP1_SHIFT          0x00u
    /* Status Register Interrupt Enable Bit Locations - UDB Status Interrupt Mask match Status Bit Locations*/
    #define PWMtriggen_STATUS_KILL_INT_EN_MASK_SHIFT          PWMtriggen_STATUS_KILL_SHIFT          
    #define PWMtriggen_STATUS_FIFONEMPTY_INT_EN_MASK_SHIFT    PWMtriggen_STATUS_FIFONEMPTY_SHIFT    
    #define PWMtriggen_STATUS_FIFOFULL_INT_EN_MASK_SHIFT      PWMtriggen_STATUS_FIFOFULL_SHIFT        
    #define PWMtriggen_STATUS_TC_INT_EN_MASK_SHIFT            PWMtriggen_STATUS_TC_SHIFT            
    #define PWMtriggen_STATUS_CMP2_INT_EN_MASK_SHIFT          PWMtriggen_STATUS_CMP2_SHIFT          
    #define PWMtriggen_STATUS_CMP1_INT_EN_MASK_SHIFT          PWMtriggen_STATUS_CMP1_SHIFT   
    /* Status Register Bit Masks */
    #define PWMtriggen_STATUS_KILL            (uint8)((uint8)0x00u << PWMtriggen_STATUS_KILL_SHIFT )
    #define PWMtriggen_STATUS_FIFOFULL        (uint8)((uint8)0x01u << PWMtriggen_STATUS_FIFOFULL_SHIFT)
    #define PWMtriggen_STATUS_FIFONEMPTY      (uint8)((uint8)0x01u << PWMtriggen_STATUS_FIFONEMPTY_SHIFT)
    #define PWMtriggen_STATUS_TC              (uint8)((uint8)0x01u << PWMtriggen_STATUS_TC_SHIFT)
    #define PWMtriggen_STATUS_CMP2            (uint8)((uint8)0x01u << PWMtriggen_STATUS_CMP2_SHIFT) 
    #define PWMtriggen_STATUS_CMP1            (uint8)((uint8)0x01u << PWMtriggen_STATUS_CMP1_SHIFT)
    /* Status Register Interrupt Bit Masks  - UDB Status Interrupt Mask match Status Bit Locations */
    #define PWMtriggen_STATUS_KILL_INT_EN_MASK            PWMtriggen_STATUS_KILL
    #define PWMtriggen_STATUS_FIFOFULL_INT_EN_MASK        PWMtriggen_STATUS_FIFOFULL
    #define PWMtriggen_STATUS_FIFONEMPTY_INT_EN_MASK      PWMtriggen_STATUS_FIFONEMPTY
    #define PWMtriggen_STATUS_TC_INT_EN_MASK              PWMtriggen_STATUS_TC
    #define PWMtriggen_STATUS_CMP2_INT_EN_MASK            PWMtriggen_STATUS_CMP2
    #define PWMtriggen_STATUS_CMP1_INT_EN_MASK            PWMtriggen_STATUS_CMP1
                                                          
    /* Datapath Auxillary Control Register definitions */
    #define PWMtriggen_AUX_CTRL_FIFO0_CLR     0x01u
    #define PWMtriggen_AUX_CTRL_FIFO1_CLR     0x02u
    #define PWMtriggen_AUX_CTRL_FIFO0_LVL     0x04u
    #define PWMtriggen_AUX_CTRL_FIFO1_LVL     0x08u
    #define PWMtriggen_STATUS_ACTL_INT_EN_MASK  0x10u /* As defined for the ACTL Register */
#endif /* PWMtriggen_UsingFixedFunction */

#endif  /* CY_PWM_PWMtriggen_H */


/* [] END OF FILE */
