/*******************************************************************************
* File Name: TrigHCSRO4.c  
* Version 1.90
*
* Description:
*  This file contains API to enable firmware control of a Pins component.
*
* Note:
*
********************************************************************************
* Copyright 2008-2012, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
*******************************************************************************/

#include "cytypes.h"
#include "TrigHCSRO4.h"


/*******************************************************************************
* Function Name: TrigHCSRO4_Write
********************************************************************************
*
* Summary:
*  Assign a new value to the digital port's data output register.  
*
* Parameters:  
*  prtValue:  The value to be assigned to the Digital Port. 
*
* Return: 
*  None 
*  
*******************************************************************************/
void TrigHCSRO4_Write(uint8 value) 
{
    uint8 staticBits = (TrigHCSRO4_DR & (uint8)(~TrigHCSRO4_MASK));
    TrigHCSRO4_DR = staticBits | ((uint8)(value << TrigHCSRO4_SHIFT) & TrigHCSRO4_MASK);
}


/*******************************************************************************
* Function Name: TrigHCSRO4_SetDriveMode
********************************************************************************
*
* Summary:
*  Change the drive mode on the pins of the port.
* 
* Parameters:  
*  mode:  Change the pins to this drive mode.
*
* Return: 
*  None
*
*******************************************************************************/
void TrigHCSRO4_SetDriveMode(uint8 mode) 
{
	CyPins_SetPinDriveMode(TrigHCSRO4_0, mode);
}


/*******************************************************************************
* Function Name: TrigHCSRO4_Read
********************************************************************************
*
* Summary:
*  Read the current value on the pins of the Digital Port in right justified 
*  form.
*
* Parameters:  
*  None 
*
* Return: 
*  Returns the current value of the Digital Port as a right justified number
*  
* Note:
*  Macro TrigHCSRO4_ReadPS calls this function. 
*  
*******************************************************************************/
uint8 TrigHCSRO4_Read(void) 
{
    return (TrigHCSRO4_PS & TrigHCSRO4_MASK) >> TrigHCSRO4_SHIFT;
}


/*******************************************************************************
* Function Name: TrigHCSRO4_ReadDataReg
********************************************************************************
*
* Summary:
*  Read the current value assigned to a Digital Port's data output register
*
* Parameters:  
*  None 
*
* Return: 
*  Returns the current value assigned to the Digital Port's data output register
*  
*******************************************************************************/
uint8 TrigHCSRO4_ReadDataReg(void) 
{
    return (TrigHCSRO4_DR & TrigHCSRO4_MASK) >> TrigHCSRO4_SHIFT;
}


/* If Interrupts Are Enabled for this Pins component */ 
#if defined(TrigHCSRO4_INTSTAT) 

    /*******************************************************************************
    * Function Name: TrigHCSRO4_ClearInterrupt
    ********************************************************************************
    *
    * Summary:
    *  Clears any active interrupts attached to port and returns the value of the 
    *  interrupt status register.
    *
    * Parameters:  
    *  None 
    *
    * Return: 
    *  Returns the value of the interrupt status register
    *  
    *******************************************************************************/
    uint8 TrigHCSRO4_ClearInterrupt(void) 
    {
        return (TrigHCSRO4_INTSTAT & TrigHCSRO4_MASK) >> TrigHCSRO4_SHIFT;
    }

#endif /* If Interrupts Are Enabled for this Pins component */ 


/* [] END OF FILE */
