/*******************************************************************************
* File Name: UltraTrigOut.c  
* Version 1.90
*
* Description:
*  This file contains API to enable firmware control of a Pins component.
*
* Note:
*
********************************************************************************
* Copyright 2008-2012, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
*******************************************************************************/

#include "cytypes.h"
#include "UltraTrigOut.h"


/*******************************************************************************
* Function Name: UltraTrigOut_Write
********************************************************************************
*
* Summary:
*  Assign a new value to the digital port's data output register.  
*
* Parameters:  
*  prtValue:  The value to be assigned to the Digital Port. 
*
* Return: 
*  None 
*  
*******************************************************************************/
void UltraTrigOut_Write(uint8 value) 
{
    uint8 staticBits = (UltraTrigOut_DR & (uint8)(~UltraTrigOut_MASK));
    UltraTrigOut_DR = staticBits | ((uint8)(value << UltraTrigOut_SHIFT) & UltraTrigOut_MASK);
}


/*******************************************************************************
* Function Name: UltraTrigOut_SetDriveMode
********************************************************************************
*
* Summary:
*  Change the drive mode on the pins of the port.
* 
* Parameters:  
*  mode:  Change the pins to this drive mode.
*
* Return: 
*  None
*
*******************************************************************************/
void UltraTrigOut_SetDriveMode(uint8 mode) 
{
	CyPins_SetPinDriveMode(UltraTrigOut_0, mode);
}


/*******************************************************************************
* Function Name: UltraTrigOut_Read
********************************************************************************
*
* Summary:
*  Read the current value on the pins of the Digital Port in right justified 
*  form.
*
* Parameters:  
*  None 
*
* Return: 
*  Returns the current value of the Digital Port as a right justified number
*  
* Note:
*  Macro UltraTrigOut_ReadPS calls this function. 
*  
*******************************************************************************/
uint8 UltraTrigOut_Read(void) 
{
    return (UltraTrigOut_PS & UltraTrigOut_MASK) >> UltraTrigOut_SHIFT;
}


/*******************************************************************************
* Function Name: UltraTrigOut_ReadDataReg
********************************************************************************
*
* Summary:
*  Read the current value assigned to a Digital Port's data output register
*
* Parameters:  
*  None 
*
* Return: 
*  Returns the current value assigned to the Digital Port's data output register
*  
*******************************************************************************/
uint8 UltraTrigOut_ReadDataReg(void) 
{
    return (UltraTrigOut_DR & UltraTrigOut_MASK) >> UltraTrigOut_SHIFT;
}


/* If Interrupts Are Enabled for this Pins component */ 
#if defined(UltraTrigOut_INTSTAT) 

    /*******************************************************************************
    * Function Name: UltraTrigOut_ClearInterrupt
    ********************************************************************************
    *
    * Summary:
    *  Clears any active interrupts attached to port and returns the value of the 
    *  interrupt status register.
    *
    * Parameters:  
    *  None 
    *
    * Return: 
    *  Returns the value of the interrupt status register
    *  
    *******************************************************************************/
    uint8 UltraTrigOut_ClearInterrupt(void) 
    {
        return (UltraTrigOut_INTSTAT & UltraTrigOut_MASK) >> UltraTrigOut_SHIFT;
    }

#endif /* If Interrupts Are Enabled for this Pins component */ 


/* [] END OF FILE */
