/*******************************************************************************
* File Name: TrigHCSR04.c  
* Version 2.10
*
* Description:
*  This file contains API to enable firmware control of a Pins component.
*
* Note:
*
********************************************************************************
* Copyright 2008-2014, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
*******************************************************************************/

#include "cytypes.h"
#include "TrigHCSR04.h"

#define SetP4PinDriveMode(shift, mode)  \
    do { \
        TrigHCSR04_PC =   (TrigHCSR04_PC & \
                                (uint32)(~(uint32)(TrigHCSR04_DRIVE_MODE_IND_MASK << (TrigHCSR04_DRIVE_MODE_BITS * (shift))))) | \
                                (uint32)((uint32)(mode) << (TrigHCSR04_DRIVE_MODE_BITS * (shift))); \
    } while (0)


/*******************************************************************************
* Function Name: TrigHCSR04_Write
********************************************************************************
*
* Summary:
*  Assign a new value to the digital port's data output register.  
*
* Parameters:  
*  prtValue:  The value to be assigned to the Digital Port. 
*
* Return: 
*  None 
*  
*******************************************************************************/
void TrigHCSR04_Write(uint8 value) 
{
    uint8 drVal = (uint8)(TrigHCSR04_DR & (uint8)(~TrigHCSR04_MASK));
    drVal = (drVal | ((uint8)(value << TrigHCSR04_SHIFT) & TrigHCSR04_MASK));
    TrigHCSR04_DR = (uint32)drVal;
}


/*******************************************************************************
* Function Name: TrigHCSR04_SetDriveMode
********************************************************************************
*
* Summary:
*  Change the drive mode on the pins of the port.
* 
* Parameters:  
*  mode:  Change the pins to one of the following drive modes.
*
*  TrigHCSR04_DM_STRONG     Strong Drive 
*  TrigHCSR04_DM_OD_HI      Open Drain, Drives High 
*  TrigHCSR04_DM_OD_LO      Open Drain, Drives Low 
*  TrigHCSR04_DM_RES_UP     Resistive Pull Up 
*  TrigHCSR04_DM_RES_DWN    Resistive Pull Down 
*  TrigHCSR04_DM_RES_UPDWN  Resistive Pull Up/Down 
*  TrigHCSR04_DM_DIG_HIZ    High Impedance Digital 
*  TrigHCSR04_DM_ALG_HIZ    High Impedance Analog 
*
* Return: 
*  None
*
*******************************************************************************/
void TrigHCSR04_SetDriveMode(uint8 mode) 
{
	SetP4PinDriveMode(TrigHCSR04__0__SHIFT, mode);
}


/*******************************************************************************
* Function Name: TrigHCSR04_Read
********************************************************************************
*
* Summary:
*  Read the current value on the pins of the Digital Port in right justified 
*  form.
*
* Parameters:  
*  None 
*
* Return: 
*  Returns the current value of the Digital Port as a right justified number
*  
* Note:
*  Macro TrigHCSR04_ReadPS calls this function. 
*  
*******************************************************************************/
uint8 TrigHCSR04_Read(void) 
{
    return (uint8)((TrigHCSR04_PS & TrigHCSR04_MASK) >> TrigHCSR04_SHIFT);
}


/*******************************************************************************
* Function Name: TrigHCSR04_ReadDataReg
********************************************************************************
*
* Summary:
*  Read the current value assigned to a Digital Port's data output register
*
* Parameters:  
*  None 
*
* Return: 
*  Returns the current value assigned to the Digital Port's data output register
*  
*******************************************************************************/
uint8 TrigHCSR04_ReadDataReg(void) 
{
    return (uint8)((TrigHCSR04_DR & TrigHCSR04_MASK) >> TrigHCSR04_SHIFT);
}


/* If Interrupts Are Enabled for this Pins component */ 
#if defined(TrigHCSR04_INTSTAT) 

    /*******************************************************************************
    * Function Name: TrigHCSR04_ClearInterrupt
    ********************************************************************************
    *
    * Summary:
    *  Clears any active interrupts attached to port and returns the value of the 
    *  interrupt status register.
    *
    * Parameters:  
    *  None 
    *
    * Return: 
    *  Returns the value of the interrupt status register
    *  
    *******************************************************************************/
    uint8 TrigHCSR04_ClearInterrupt(void) 
    {
		uint8 maskedStatus = (uint8)(TrigHCSR04_INTSTAT & TrigHCSR04_MASK);
		TrigHCSR04_INTSTAT = maskedStatus;
        return maskedStatus >> TrigHCSR04_SHIFT;
    }

#endif /* If Interrupts Are Enabled for this Pins component */ 


/* [] END OF FILE */
